'''
Created on 24.10.2011

@author: xaralis
'''
import os

from django.http import HttpResponse, Http404
from static_sitemaps import conf

from static_sitemaps.util import _lazy_load


try:
    from django.conf.urls import patterns, url
except ImportError:  # django < 1.4
    from django.conf.urls.defaults import patterns, url


def serve_index(request):
    storage = _lazy_load(conf.STORAGE_CLASS)()
    path = os.path.join(conf.ROOT_DIR, 'sitemap.xml')
    if not storage.exists(path):
        raise Http404('No sitemap index file found on %r. Run django-admin.py '
                      'refresh_sitemap first.' % path)

    f = storage.open(path)
    content = f.readlines()
    f.close()
    return HttpResponse(content, mimetype='application/xml')

urlpatterns = patterns('',
    url(r'^', serve_index, name='static_sitemaps_index'),
)



"""
Reusable app meant to allow users to serve sitemap files by webserver
instead of Django and generate sitemaps by running cron command.

This results in better performance for sites with loads of content and/or URLS.

App is dependent on original django.contrib.sitemaps application which
has to be included in order for this to work.
"""
__versionstr__ = '2.1.4'



from django.core.management.base import NoArgsCommand

from static_sitemaps.generator import SitemapGenerator

__author__ = 'xaralis'


class Command(NoArgsCommand):
    command = None
    help = 'Generates sitemaps files to a predefined directory.'

    def handle_noargs(self, **options):
        generator = SitemapGenerator(int(options.get('verbosity', 0)))
        generator.write()



from importlib import import_module

from django.core.exceptions import ImproperlyConfigured


def _lazy_load(class_path):
    module, attr = class_path.rsplit('.', 1)
    try:
        mod = import_module(module)
    except ImportError, e:
        raise ImproperlyConfigured('Error importing module %s: "%s"' %
                                   (module, e))
    try:
        instance = getattr(mod, attr)
        return instance
    except AttributeError:
        raise ImproperlyConfigured('Module "%s" does not define a "%s" '
                                   'class.' % (module, attr))
